###################################################
### chunk number 1: library.load
###################################################
library(MISA)


###################################################
### chunk number 2: foo
###################################################
options(keep.source = TRUE, width = 60)
foo = packageDescription("MISA")


###################################################
### chunk number 3: simulation
###################################################
data(dna.snp.full)
p.full <- dim(dna.snp.full)[2]-2
data(sim.info)


###################################################
### chunk number 4: marg.screen
###################################################
marg.bf <- bf4assoc(D=as.numeric(dna.snp.full$case) - 1,
                    X=as.matrix(dna.snp.full$age),
                    XS=as.matrix(dna.snp.full[, -c(1,2)]),
                    Ns=p.full, Nx=1, snpsd=0.25, Prior=0, MinCount=1.9,
                    MaxIt=1000,RelTol=10e-8)
max.bf <- apply(marg.bf[, 3:5], 1, max)
dna.snp <- dna.snp.full[,c(TRUE, TRUE, max.bf > 1)]
p <- dim(dna.snp)[2] - 2


###################################################
### chunk number 5: EMC
###################################################
start.snp <- rep(FALSE,p)
start.snp[c(3,7)] <- TRUE
emc.out <- Gene.EMC(data=dna.snp, force=c("age"), fitness="AIC.BB", b=p, a=1,
                   start.snps=start.snp, n.iter=10, N=5, tmax=5, tlone=1,
                    qm=.25, display.acc=TRUE, display.acc.ex=FALSE, log=FALSE)


###################################################
### chunk number 6: Convergence
###################################################
data(emc.out.1)
data(emc.out.2)
emc.out <- list(emc.out.1,emc.out.2)
converge.EMC(emc.out, plot.type="all", bandwidth=1000, b=p, a=1)


###################################################
### chunk number 7: figure1
###################################################
data(emc.out.1)
data(emc.out.2)
emc.out <- list(emc.out.1,emc.out.2)
converge.EMC(emc.out, plot.type="all", bandwidth=1000, b=p, a=1)


###################################################
### chunk number 8: Combine
###################################################
##Combine emc.out.1 and emc.out.2 to get results from both runs.
data(emc.out.1)
data(emc.out.2)
combo.out <- combine.EMC(list(emc.out.1, emc.out.2))


###################################################
### chunk number 9: Post
###################################################
##Calculate Posterior Probabilities
data(sim.info)
post.prob.out <- post.prob(combo.out, sim.info, b=p)
post.prob.out$BF


###################################################
### chunk number 10: Summarys
###################################################
model.inc(post.prob.out,num.models=100,num.snps=p,inc.typ="s")


###################################################
### chunk number 11: Summaryg
###################################################
model.inc(post.prob.out,num.models=100,num.genes=6,inc.typ="g")


###################################################
### chunk number 12: figure2
###################################################
model.inc(post.prob.out,num.models=100,num.snps=p,inc.typ="s")


###################################################
### chunk number 13: figure3
###################################################
model.inc(post.prob.out,num.models=100,num.genes=6,inc.typ="g")


